@@ -26,9 +26,9 @@ Handler = TypeVar("Handler")
 
 
 async def empty_receive() -> "NoReturn":  # pragma: no cover
-    """Raise a `RuntimeError`.
+    """Raise a ``RuntimeError``.
 
-    Serves as a placeholder `send` function.
+    Serves as a placeholder ``send`` function.
 
     Raises:
         RuntimeError
@@ -37,9 +37,9 @@ async def empty_receive() -> "NoReturn":  # pragma: no cover
 
 
 async def empty_send(_: "Message") -> "NoReturn":  # pragma: no cover
-    """Raise a `RuntimeError`.
+    """Raise a ``RuntimeError``.
 
-    Serves as a placeholder `send` function.
+    Serves as a placeholder ``send`` function.
 
     Args:
         _: An ASGI message
@@ -63,7 +63,7 @@ class ASGIConnection(Generic[Handler, User, Auth]):
     """The ASGI send function."""
 
     def __init__(self, scope: "Scope", receive: "Receive" = empty_receive, send: "Send" = empty_send) -> None:
-        """Initialize `ASGIConnection`.
+        """Initialize ``ASGIConnection``.
 
         Args:
             scope: The ASGI connection scope.
@@ -81,16 +81,16 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def app(self) -> "Starlite":
-        """Return the `app` for this connection.
+        """Return the ``app`` for this connection.
 
         Returns:
-            The [Starlite][starlite.app.Starlite] application instance
+            The :class:`Starlite <starlite.app.Starlite>` application instance
         """
         return self.scope["app"]
 
     @property
     def route_handler(self) -> Handler:
-        """Return the `route_handler` for this connection.
+        """Return the ``route_handler`` for this connection.
 
         Returns:
             The target route handler instance.
@@ -99,7 +99,7 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def state(self) -> State:
-        """Return the `State` of this connection.
+        """Return the ``State`` of this connection.
 
         Returns:
             A State instance constructed from the scope["state"] value.
@@ -108,7 +108,7 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def url(self) -> URL:
-        """Return the URL of this connection's `Scope`.
+        """Return the URL of this connection's ``Scope``.
 
         Returns:
             A URL instance constructed from the request's scope.
@@ -119,7 +119,7 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def base_url(self) -> URL:
-        """Return the base URL of this connection's `Scope`.
+        """Return the base URL of this connection's ``Scope``.
 
         Returns:
             A URL instance constructed from the request's scope, representing only the base part
@@ -138,7 +138,7 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def headers(self) -> Headers:
-        """Return the headers of this connection's `Scope`.
+        """Return the headers of this connection's ``Scope``.
 
         Returns:
             A Headers instance with the request's scope["headers"] value.
@@ -150,7 +150,7 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def query_params(self) -> MultiDict:
-        """Return the query parameters of this connection's `Scope`.
+        """Return the query parameters of this connection's ``Scope``.
 
         Returns:
             A normalized dict of query parameters. Multiple values for the same key are returned as a list.
@@ -161,7 +161,7 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def path_params(self) -> Dict[str, Any]:
-        """Return the `path_params` of this connection's `Scope`.
+        """Return the ``path_params`` of this connection's ``Scope``.
 
         Returns:
             A string keyed dictionary of path parameter values.
@@ -170,7 +170,7 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def cookies(self) -> Dict[str, str]:
-        """Return the `cookies` of this connection's `Scope`.
+        """Return the ``cookies`` of this connection's ``Scope``.
 
         Returns:
             Returns any cookies stored in the header as a parsed dictionary.
@@ -185,7 +185,7 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def client(self) -> Optional[Address]:
-        """Return the `client` data of this connection's `Scope`.
+        """Return the ``client`` data of this connection's ``Scope``.
 
         Returns:
             A two tuple of the host name and port number.
@@ -195,10 +195,10 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def auth(self) -> Auth:
-        """Return the `auth` data of this connection's `Scope`.
+        """Return the ``auth`` data of this connection's ``Scope``.
 
         Raises:
-            ImproperlyConfiguredException: If 'auth' is not set in scope via an 'AuthMiddleware', raises an exception
+            ImproperlyConfiguredException: If ``auth`` is not set in scope via an ``AuthMiddleware``, raises an exception
 
         Returns:
             A type correlating to the generic variable Auth.
@@ -209,10 +209,10 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def user(self) -> User:
-        """Return the `user` data of this connection's `Scope`.
+        """Return the ``user`` data of this connection's ``Scope``.
 
         Raises:
-            ImproperlyConfiguredException: If 'user' is not set in scope via an 'AuthMiddleware', raises an exception
+            ImproperlyConfiguredException: If ``user`` is not set in scope via an ``AuthMiddleware``, raises an exception
 
         Returns:
             A type correlating to the generic variable User.
@@ -223,7 +223,7 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def session(self) -> Dict[str, Any]:
-        """Return the session for this connection if a session was previously set in the `Scope`
+        """Return the session for this connection if a session was previously set in the ``Scope``
 
         Returns:
             A dictionary representing the session value - if existing.
@@ -239,29 +239,29 @@ class ASGIConnection(Generic[Handler, User, Auth]):
 
     @property
     def logger(self) -> "Logger":
-        """Return the `Logger` instance for this connection.
+        """Return the ``Logger`` instance for this connection.
 
         Returns:
-            A 'Logger' instance.
+            A ``Logger`` instance.
 
         Raises:
-            ImproperlyConfiguredException: if 'log_config' has not been passed to the Starlite constructor.
+            ImproperlyConfiguredException: if ``log_config`` has not been passed to the Starlite constructor.
         """
         return self.app.get_logger()
 
     @property
     def cache(self) -> "Cache":
-        """Return the `Cache` for this connection.
+        """Return the ``Cache`` for this connection.
 
         Returns:
-            A 'Cache' instance.
+            A ``Cache`` instance.
         """
         return self.app.cache
 
     def set_session(self, value: Union[Dict[str, Any], "BaseModel", "EmptyType"]) -> None:
-        """Set the session in the connection's `Scope`.
+        """Set the session in the connection's ``Scope``.
 
-        If the [Starlite SessionMiddleware][starlite.middleware.session.SessionMiddleware] is
+        If the :class:`Starlite SessionMiddleware <starlite.middleware.session.SessionMiddleware>` is
         enabled, the session will be added to the response as a cookie header.
 
         Args:
@@ -273,9 +273,9 @@ class ASGIConnection(Generic[Handler, User, Auth]):
         self.scope["session"] = value
 
     def clear_session(self) -> None:
-        """Remove the session from the connection's `Scope`.
+        """Remove the session from the connection's ``Scope``.
 
-        If the [Starlite SessionMiddleware][starlite.middleware.session.SessionMiddleware] is
+        If the :class:`Starlite SessionMiddleware <starlite.middleware.session.SessionMiddleware>` is
         enabled, this will cause the session data to be cleared.
 
         Returns:
@@ -287,11 +287,12 @@ class ASGIConnection(Generic[Handler, User, Auth]):
         """Return the url for a given route handler name.
 
         Args:
-            name: The 'name' of the request route handler.
+            name: The ``name`` of the request route handler.
             **path_parameters: Values for path parameters in the route
 
         Raises:
-            NoRouteMatchFoundException: If route with 'name' does not exist, path parameters are missing or have a wrong type.
+            NoRouteMatchFoundException: If route with ``name`` does not exist, path parameters are missing or have a
+                wrong type.
 
         Returns:
             A string representing the absolute url of the route handler.
@@ -309,7 +310,7 @@ class ASGIConnection(Generic[Handler, User, Auth]):
             file_path: a string containing path to an asset.
 
         Raises:
-            NoRouteMatchFoundException: If static files handler with 'name' does not exist.
+            NoRouteMatchFoundException: If static files handler with ``name`` does not exist.
 
         Returns:
             A string representing absolute url to the asset.
