@@ -13,7 +13,7 @@ CAPITAL_LETTERS_PATTERN = re.compile(r"(?=[A-Z])")
 
 
 def pascal_case_to_text(string: str) -> str:
-    """Given a 'PascalCased' string, return its split form- 'Pascal Cased'."""
+    """Given a ``PascalCased`` string, return its split form- 'Pascal Cased'."""
     return " ".join(re.split(CAPITAL_LETTERS_PATTERN, string)).strip()
 
 
@@ -28,6 +28,6 @@ def get_openapi_type_for_complex_type(field: "ModelField") -> "OpenAPIType":
         raise ImproperlyConfiguredException(
             f"Parameter '{field.name}' with type '{field.outer_type_}' could not be mapped to an Open API type. "
             f"This can occur if a user-defined generic type is resolved as a parameter. If '{field.name}' should "
-            "not be documented as a parameter, annotate it using the `Dependency` function, e.g., "
+            "not be documented as a parameter, annotate it using the ``Dependency`` function, e.g., "
             f"`{field.name}: ... = Dependency(...)`."
         ) from e
