@@ -10,7 +10,17 @@ from ipaddress import (
 )
 from pathlib import Path, PurePath
 from re import Pattern
-from typing import TYPE_CHECKING, Any, Callable, Dict, Optional, Union
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    Dict,
+    Optional,
+    Type,
+    TypeVar,
+    Union,
+    overload,
+)
 
 import msgspec
 from pydantic import (
@@ -26,10 +36,13 @@ from pydantic.color import Color
 from pydantic.json import decimal_encoder
 
 from starlite.exceptions import SerializationException
+from starlite.types import Empty
 
 if TYPE_CHECKING:
     from starlite.types import TypeEncodersMap
 
+T = TypeVar("T")
+
 DEFAULT_TYPE_ENCODERS: "TypeEncodersMap" = {
     Path: str,
     PurePath: str,
@@ -65,7 +78,7 @@ DEFAULT_TYPE_ENCODERS: "TypeEncodersMap" = {
 
 
 def default_serializer(value: Any, type_encoders: Optional[Dict[Any, Callable[[Any], Any]]] = None) -> Any:
-    """Transform values non-natively supported by `msgspec`
+    """Transform values non-natively supported by ``msgspec``
 
     Args:
         value: A value to serialize#
@@ -87,17 +100,19 @@ def default_serializer(value: Any, type_encoders: Optional[Dict[Any, Callable[[A
 
 
 def dec_hook(type_: Any, value: Any) -> Any:  # pragma: no cover
-    """Transform values non-natively supported by `msgspec`
+    """Transform values non-natively supported by ``msgspec``
 
     Args:
         type_: Encountered type
         value: Value to coerce
 
     Returns:
-        A `msgspec`-supported type
+        A ``msgspec``-supported type
     """
     if issubclass(type_, BaseModel):
-        return type_(**value)
+        return type_.parse_obj(value)
+    if issubclass(type_, (Path, PurePath)):
+        return type_(value)
     raise TypeError(f"Unsupported type: {type(value)!r}")
 
 
@@ -118,7 +133,7 @@ def encode_json(obj: Any, default: Optional[Callable[[Any], Any]] = default_seri
         JSON as bytes
 
     Raises:
-        SerializationException: If error encoding `obj`.
+        SerializationException: If error encoding ``obj``.
     """
     try:
         if default is None or default is default_serializer:
@@ -128,20 +143,33 @@ def encode_json(obj: Any, default: Optional[Callable[[Any], Any]] = default_seri
         raise SerializationException(str(msgspec_error)) from msgspec_error
 
 
+@overload
 def decode_json(raw: Union[str, bytes]) -> Any:
+    ...
+
+
+@overload
+def decode_json(raw: Union[str, bytes], type_: Type[T]) -> T:
+    ...
+
+
+def decode_json(raw: Union[str, bytes], type_: Any = Empty) -> Any:
     """Decode a JSON string/bytes into an object.
 
     Args:
         raw: Value to decode
+        type_: An optional type to decode the data into
 
     Returns:
         An object
 
     Raises:
-        SerializationException: If error decoding `raw`.
+        SerializationException: If error decoding ``raw``.
     """
     try:
-        return _msgspec_json_decoder.decode(raw)
+        if type_ is Empty:
+            return _msgspec_json_decoder.decode(raw)
+        return msgspec.json.decode(raw, dec_hook=dec_hook, type=type_)
     except msgspec.DecodeError as msgspec_error:
         raise SerializationException(str(msgspec_error)) from msgspec_error
 
@@ -157,7 +185,7 @@ def encode_msgpack(obj: Any, enc_hook: Optional[Callable[[Any], Any]] = default_
         MessagePack as bytes
 
     Raises:
-        SerializationException: If error encoding `obj`.
+        SerializationException: If error encoding ``obj``.
     """
     try:
         if enc_hook is None or enc_hook is default_serializer:
@@ -167,19 +195,32 @@ def encode_msgpack(obj: Any, enc_hook: Optional[Callable[[Any], Any]] = default_
         raise SerializationException(str(msgspec_error)) from msgspec_error
 
 
+@overload
 def decode_msgpack(raw: bytes) -> Any:
+    ...
+
+
+@overload
+def decode_msgpack(raw: bytes, type_: Type[T]) -> T:
+    ...
+
+
+def decode_msgpack(raw: bytes, type_: Any = Empty) -> Any:
     """Decode a MessagePack string/bytes into an object.
 
     Args:
         raw: Value to decode
+        type_: An optional type to decode the data into
 
     Returns:
         An object
 
     Raises:
-        SerializationException: If error decoding `raw`.
+        SerializationException: If error decoding ``raw``.
     """
     try:
-        return _msgspec_msgpack_decoder.decode(raw)
+        if type_ is Empty:
+            return _msgspec_msgpack_decoder.decode(raw)
+        return msgspec.msgpack.decode(raw, dec_hook=dec_hook, type=type_)
     except msgspec.DecodeError as msgspec_error:
         raise SerializationException(str(msgspec_error)) from msgspec_error
